#include "hmg.ch"

*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*
 /* 
Goal:   CamelCase converts strings

Syntax: CamelCase( cText [String to be converted]
				  <lForce> [Optional, Default: .T.]
				  <aRemChar> [Optional, Default: space and underscore] )

				  Author: Pablo Csar Arrascaeta  IN MEMORIAM 
Version: 1.0

CamelCase "Convention" for this procedure:
a. Verifies if the string is completly in upper or lower case.
b. In case lForce be not omitted, with value .F. and item A
   been false, CamelCase will not convert it, remaining as is it.
c. Being pass lForce as .T. will convert it.
d. If array is passed in aRemChar parameter, will consider these
   elements to be removed.
e. Upper case will converted followed by characters like as:
   Space      -> " "
   UnderScore -> "_"
   Dot        -> "."
   Hyphen     -> "-"
   Slash      -> "/"
   BackSlash  -> "\"

Reasons to use: 
	- As opposed to allowing programmers to choose any character sequence
        - To reduce the effort needed to read and understand source code
        - To enhance source code appearance 
         (for example, by disallowing overly long names or unclear abbreviations)
*/   
*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*

*-------------------------------------------------*
Function CamelCase (cString,lForce,aRemChar)
*-------------------------------------------------*

Local cLower:=HMG_Lower(cString), lNext:=.T.
Local n1, n2, n3, nRound1, nRound2, nRound3
Local aString, cCheck:=" "+"_"+"-"+"."+"/"+"\", cChar

DEFAULT lForce:=.T.
DEFAULT aRemChar:={" ","_",".","-","/","\"}

If lForce
   nRound1:=Len(aRemChar)
Else
   If (cString==HMG_Upper(cString)) .or. (cString==HMG_Lower(cString))
      nRound1:=Len(aRemChar)
   Else
	  cRet:=cString
	  nRound1:=0
   Endif
Endif
If nRound1>0
   cString:=HMG_Lower(cString)
Endif
For n1=1 To nRound1
    If aRemChar[n1] $ cString
       aString:= hb_ATokens ( cString, aRemChar[n1] )
       cString:=""
       nRound2:=Len(aString)
	   For n2=1 To nRound2
	       cString:=cString+HMG_Upper(HB_USubStr(aString[n2],1,1))+HB_USubStr(aString[n2],2)
	   Next
	Endif
	cRet:=cString
Next
cRet:=""
nRound3:=HMG_Len(cString)
For n3=1 To nRound3
    cChar:=HB_USubStr(cString,n3,1)
    If cChar $ cCheck
	   If nRound1>0
	      cRet:=cRet+cChar
	   Endif
	   lNext:=.T.
	   Loop
	Endif
	If lNext
	   cRet:=cRet+HMG_Upper(cChar)
	   lNext:=.F.
	Else
	   cRet:=cRet+cChar
	Endif
Next
Return cRet

*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*







